@@ -6,7 +6,7 @@
 # KangRollGeneCancer/__init__.py
 
 # 导入核心模块
-from .core import update_network, IS_KANGROLL_PRODUCTION, KANGROLL_PRODUCTION_KEY ,test_function
+from .core import update_network, IS_KANGROLL_PRODUCTION, KANGROLL_PRODUCTION_KEY # ,test_function
 
 # 导入模型模块
 # from .models import analyze_gene
