@@ -9,7 +9,7 @@ from .multi_layer_network import update_network
 
 
 
-from .kangroll_000_protect_myself import test_function
+# from .kangroll_000_protect_myself import test_function
 
 # 如果您需要在这个 __init__.py 中导入 analyze_gene 和 config，
 # 您可以使用相对路径来导入，但这取决于您的项目结构和需求。
